function [Nriv,Nsulf,dry]=evalModel(x)

% input variable:
% x : evaluation point in search space
%       numel(x)= no. of decision variables
%       here: no. of wells = numel(x)/3
%       Format: 1. Well: x_pos_1 y_pos_1 Q_1
%               2. Well: x_pos_2 y_pos_2 Q_2
%               3. Well: x_pos_3 y_pos_3 Q_3
%               etc.
%      x_pos_i: cell index j of well i (Modflow terminology) (easting - along rows)
%      y_pos_i: cell index i of well i (Modflow terminology) (southing - along cols)
%          Q_i: injection/extraction rate of well i
%               (extraction rates are negative)

% output variables:
% Nriv: no. of particles (originating from river) captured
% Nsulf: no. of particles (originating from sulfate water plume) captured
% dry: column vector of size no. of wells containing zeros and ones.
%      if one at position i than well i ran dry (= invalid solution)

% no. of wells
nwell = numel(x)/3;

% reshaped decisionvariable vector

DV = reshape(x,3,nwell);
DV = DV';
DV(:,1:2) = floor(DV(:,1:2)) ; % now well positions are integers!
x = reshape(DV',3*nwell,1);
disp('  ')
disp('Working on the following candidate solution:')
disp(x')
disp('  ')
% given (header entries in wel.dat):
item1 = nwell;
item2 = 50;
item3 = nwell;
layer = 1;

% modify wel.dat according to input (well line format: layer row col Q)
fid=fopen('wel.dat','w');
fprintf(fid,'%9d %9d\n',[item1,item2]);
fprintf(fid,'%9d\n',[item3]);
for i=1:nwell
   % i
    fprintf(fid,'%9d %9d %9d %12.8f\n',[layer,x(((i-1)*3)+2),x(((i-1)*3)+1),x(((i-1)*3)+3)]);
    % [layer,x((i-1)*3+2),x((i-1)*3+1),x((i-1)*3+3)]
   % (i-1)*3+2,(i-1)*3+1,(i-1)*3+3
end
st=fclose(fid);
if st <0
    disp('      ')
    disp('***********************************')
    disp('closing of wel.dat failed!!!')
    disp('***********************************')    
    disp('      ')
end
% run modflow 
eval('! mf2k.exe < mf.in >junk.dat');

% check for dry cells, i.e. check output.dat with ulf.echse for "DRY("
eval('!ulf.echse output.dat dry.dat DRY( > ulf.junk');
fid=fopen('dry.dat','r'); % 
[dry,count]=fscanf(fid,'%d',1);
stat=fclose(fid);
if stat <0
    disp('      ')
    disp('***********************************')
    disp('closing of dry.dat failed!!!')
    disp('***********************************')    
    disp('      ')
end



%
% run Modpath for the river constraint
%
% =========================================================================
eval('! ModPathRiv.bat'); % latest test shows Mpath5_0 is able to read the heads.dat
% ========================================================================
% read heads.dat @ well locations

% read modpath output
% output file: endpoint
% format of endpoint file: fl = final location
% zoneCodefl Jfl Ifl Kfl Xfl Yfl Zfl zlocfl TotTracTime X Y zloc J I K zoneCode
% timeStepNo PartTermTime ReleaseTime
%
fid=fopen('endpoint.dat','r');

[dummy,count] = fscanf(fid,'%41c',1);

% Watch out: fscanf reads columnwise... 
[A,count] = fscanf(fid,'%g',[19 inf]);  % inf: read to end of file

stat=fclose(fid);

A = A';

% match well locations with particle endlocations
pen1 = ismember(A(:,2),DV(:,1));
pen2 = ismember(A(:,3),DV(:,2));
pen = and(pen1,pen2);

if sum(pen)==0 % endpoint locations do not match any well locations
    Nriv=0;
else % endpoint locations match Nriv
    Nriv=sum(pen);
end

% run Modpath for the sulfate plume constraint

% =========================================================================
eval('! ModPathSul.bat'); % latest test shows Mpath5_0 is able to read the heads.dat
% ========================================================================
% read heads.dat @ well locations

% read modpath output
% output file: endpoint
% format of endpoint file: fl = final location
% zoneCodefl Jfl Ifl Kfl Xfl Yfl Zfl zlocfl TotTracTime X Y zloc J I K zoneCode
% timeStepNo PartTermTime ReleaseTime
%
fid=fopen('endpoint.dat','r');

[dummy,count] = fscanf(fid,'%41c',1);

% Watch out: fscanf reads columnwise... 
[A,count] = fscanf(fid,'%g',[19 inf]);  % inf: read to end of file

stat=fclose(fid);

A = A';

% match well locations with particle endlocations
pen1 = ismember(A(:,2),DV(:,1));
pen2 = ismember(A(:,3),DV(:,2));
pen = and(pen1,pen2);

if sum(pen)==0 % endpoint locations do not match any well locations
    Nsulf=0;
else % endpoint locations match Nriv
    Nsulf=sum(pen);
end





