function [fit]=objFunc(x)

% objective function for use with CMA-ES
% the objective is extraction rate maximization

% input variable:
% x : evaluation point in search space
%       numel(x)= no. of decision variables
%       here: no. of wells = numel(x)/3
%       Format: 1. Well: x_pos_1 y_pos_1 Q_1
%               2. Well: x_pos_2 y_pos_2 Q_2
%               3. Well: x_pos_3 y_pos_3 Q_3
%               etc.
%      x_pos_i: cell index j of well i
%      y_pos_i: cell index i of well i
%          Q_i: injection/extraction rate of well i
%               (extraction rates are negative)

% output variable
% fit: objective function value

nreal = 10; % no. of hydraulic conductivity fields
            % = stack size

% grid information            
ncol = 440; % no. of columns = max. no. for J index
nrow = 446; % no. of rows = max. no. for I index

% total no. of river particle 
nriv = 679;
% total no. of sulfate plume particles 
nsulf = 495;
% maximum no of allowed sulfate plume particles
sulfOff = 99;


% possibility 1: Evaluate complete stack
%
% [fitn]=evaluateAllReals(x,nreal);
%

% possibility 2: Build your own stack ordering algorithm
%
% [fitn]=evaluateRealn(x,n)
%
% n : evaluate only realization n

% 
% fitn: nreal x 3 or 1 x 3 matrix
%      first  entry: no. of captured river particles (ideal value == 0)
%      second entry: no. of captured sulfate particles (ideal value <= 19)
%       third entry: dry cells = invalid solution (only valid value == 0)
%

% implemented (naive) example objective function

[fitn]=evaluateAllReals(x,nreal)

if sum(fitn(:,3))~= 0 % dry cells 
    fit = -10000+(-1)*10^(5*sum(fitn(:,3)))+sum(x(3:3:end));
else % no dry cells
    ind=find(fitn(:,2)>sulfOff);
    if numel(ind)~=0 % sulfate plume captured at excess 
        fit=sum(x(3:3:end))-100+(-1)*5^(log(sum(fitn(:,2))));
    else
        riv = sum(fitn(:,1));
        if riv~=0 % river particels reach well faster than 50 days
            fit=sum(x(3:3:end))-100+(-1)*5^(log(sum(fitn(:,3))))+(-1)*5^(log(1+sum(fitn(:,2))));
        else % a valid solution
            fit = -sum(x(3:3:end));
        end
    end
end

% since CMA-ES expects us to minimize the objective function 
fit = -fit